.. include:: /_includes/wip_prolog.rst

:mod:`stix.core.stix_package` Module
====================================

.. module:: stix.core.stix_package

Classes
-------

.. autoclass:: STIXPackage
	:show-inheritance:
	:members:

.. autoclass:: RelatedPackages
	:show-inheritance:
	:members:
